@@ -94,6 +94,14 @@ QUrl KonqMisc::konqFilteredURL(KonqMainWindow *parent, const QString &_url, cons
             }
         }
 
+        // Show an explicit error for an unknown URL scheme, because the
+        // explanation generated by KIO::rawErrorDetail() gives useful
+        // information.
+        const QString scheme = data.uri().scheme();
+        if (!scheme.isEmpty() && !KProtocolInfo::isKnownProtocol(scheme)) {
+            return KParts::BrowserRun::makeErrorUrl(KIO::ERR_UNSUPPORTED_PROTOCOL, _url, QUrl(_url));
+        }
+
         // NOTE: a valid URL like http://kde.org always passes the filtering test.
         // As such, this point could only be reached when _url is NOT a valid URL.
         return KParts::BrowserRun::makeErrorUrl(KIO::ERR_MALFORMED_URL, _url, QUrl(_url));
