@@ -48,11 +48,16 @@
 #include "settings/webenginesettings.h"
 #include "ui/credentialsdetailswidget.h"
 
+#include <kconfigwidgets_version.h>
 #include <KCodecAction>
 #include <KIO/Global>
 
 #include <KActionCollection>
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+#include <KPluginMetaData>
+#else
 #include <KAboutData>
+#endif
 #include <KUrlLabel>
 #include <KMessageBox>
 #include <KStringHandler>
@@ -90,7 +95,7 @@ void WebEnginePart::initWebEngineUrlSchemes()
     static bool needToInitUrlSchemes = true;
     if (needToInitUrlSchemes) {
         needToInitUrlSchemes = false;
-        QVector<QByteArray> localSchemes = {"error", "konq"};
+        QVector<QByteArray> localSchemes = {"error", "konq", "tar"};
         const QStringList protocols = KProtocolInfo::protocols();
         for(const QString &prot : protocols){
             if (KProtocolInfo::defaultMimetype(prot) == "text/html") {
@@ -107,6 +112,9 @@ void WebEnginePart::initWebEngineUrlSchemes()
 }
 
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+                         const KPluginMetaData& metaData,
+#endif
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
             :KParts::ReadOnlyPart(parent),
              m_emitOpenUrlNotify(true),
@@ -123,8 +131,12 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
         prof->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(prof));
         prof->installUrlSchemeHandler("konq", new KonqUrlSchemeHandler(prof));
         prof->installUrlSchemeHandler("help", new WebEnginePartKIOHandler(prof));
+        prof->installUrlSchemeHandler("tar", new WebEnginePartKIOHandler(prof));
     }
     static WebEnginePartCookieJar s_cookieJar(prof, nullptr);
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    setMetaData(metaData);
+#else
     KAboutData about = KAboutData(QStringLiteral("webenginepart"),
                                   i18nc("Program Name", "WebEnginePart"),
                                   /*version*/ QStringLiteral("1.3.0"),
@@ -143,6 +155,7 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     about.setProductName("webenginepart/general");
 //    KComponentData componentData(&about);
     setComponentData(about, false /*don't load plugins yet*/);
+#endif
 
 #if 0
     // NOTE: If the application does not set its version number, we automatically
@@ -286,11 +299,15 @@ void WebEnginePart::initActions()
 
     KCodecAction *codecAction = new KCodecAction( QIcon::fromTheme(QStringLiteral("character-set")), i18n( "Set &Encoding" ), this, true );
     actionCollection()->addAction( QStringLiteral("setEncoding"), codecAction );
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+    connect(codecAction, &KCodecAction::codecTriggered, this, &WebEnginePart::slotSetTextEncoding);
+#else
     connect(codecAction, QOverload<QTextCodec *>::of(&KCodecAction::triggered), this, &WebEnginePart::slotSetTextEncoding);
+#endif
 
     action = new QAction(i18n("View Do&cument Source"), this);
     actionCollection()->addAction(QStringLiteral("viewDocumentSource"), action);
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_U));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_U));
     connect(action, &QAction::triggered, m_browserExtension, &WebEngineBrowserExtension::slotViewDocumentSource);
 
     action = new QAction(i18nc("Secure Sockets Layer", "SSL"), this);
